==> taxware-all-electric-contract-1.0.5-20230718.040027-30-sources.jar: com/xforceplus/taxware/contract/allelectric/message/PostRedInfoTableResultMessage.java <==
package com.xforceplus.taxware.contract.allelectric.message;

import lombok.Data;

import java.math.BigDecimal;

/**
 * 红字信息表申请结果回调消息
 * <p>
 * https://xforceplus.yuque.com/dew9bm/yagacb/hn55gs
 */
@Data
public class PostRedInfoTableResultMessage {

    @Data
    public static class Properties {

        /**
         * 业务编号
         */
        private String businessNo;

        /**
         * 调用方系统
         */
        private String fromSystem;

        /**
         * 租户id
         */
        private String tenantId;
    }

    /**
     * 错误码：成功：1，失败：其他编码
     **/
    private String code = "1";

    /**
     * 描述
     **/
    private String message;

    /**
     * 结果
     **/
    private Result result = new Result();

    @Data
    public static class Result {

        /**
         * 请求流水号
         **/
        private String taskId;

        /**
         * 红字信息表编号
         **/
        private String redLetterNumber;

        /**
         * 红字信息表状态
         * 01-无需确认
         * 02-销方录入待购方确认
         * 03-购方录入待销方确认
         */
        private String status;

        /**
         * 红字信息表申请日期时间
         * yyyyMMddHHmmss
         */
        private String dateRedApplied;

        /**
         * 是否乐企标识
         */
        private Boolean isNatureSystemFlag;

        /**
         * 红字确认单对应红票
         */
        private RedInvoice redInvoice;

        @Data
        public static class RedInvoice {

            /**
             * 发票号码
             */
            private String invoiceNo;

            /**
             * 发票类型
             * qc、qs、cz、sz
             */
            private String invoiceType;

            /**
             * 纸票发票代码（纸票红票有值）
             */
            private String paperInvoiceCode;

            /**
             * 纸票发票号码（纸票红票有值）
             */
            private String paperInvoiceNo;

            /**
             * 开票日期时间(yyyyMMddHHmmss)
             */
            private String dateIssued;

            /**
             * 二维码地址（纸票没有此字段）
             */
            private String qrCodeUrl;

            /**
             * 剩余开具额度
             */
            private BigDecimal creditLimit;

            /**
             * 剩余开具额度
             */
            private String remark;
        }
    }
}

==> taxware-all-electric-contract-1.0.6-20230915.034802-13-sources.jar: com/xforceplus/taxware/contract/allelectric/message/PostRedInfoTableResultMessage.java <==
package com.xforceplus.taxware.contract.allelectric.message;

import lombok.Data;

import java.math.BigDecimal;

/**
 * 红字信息表申请结果回调消息
 * <p>
 * https://xforceplus.yuque.com/dew9bm/yagacb/hn55gs
 */
@Data
public class PostRedInfoTableResultMessage {

    @Data
    public static class Properties {

        /**
         * 业务编号
         */
        private String businessNo;

        /**
         * 调用方系统
         */
        private String fromSystem;

        /**
         * 租户id
         */
        private String tenantId;
    }

    /**
     * 错误码：成功：1，失败：其他编码
     **/
    private String code = "1";

    /**
     * 描述
     **/
    private String message;

    /**
     * 结果
     **/
    private Result result = new Result();

    @Data
    public static class Result {

        /**
         * 请求流水号
         **/
        private String taskId;

        /**
         * 红字信息表编号
         **/
        private String redLetterNumber;

        /**
         * 红字确认单UUid
         */
        private String redLetterUuid;

        /**
         * 红字信息表状态
         * 01-无需确认
         * 02-销方录入待购方确认
         * 03-购方录入待销方确认
         */
        private String status;

        /**
         * 红字信息表申请日期时间
         * yyyyMMddHHmmss
         */
        private String dateRedApplied;

        /**
         * 是否乐企标识
         */
        private Boolean isNatureSystemFlag;

        /**
         * 是否确认即开票，即经过无需确认或对方确认后，红票会不会自动被开出
         */
        private Boolean isMakeInvoiceAfterConfirm;

        /**
         * 开具状态：有2个枚举：
         * isInvoiced-已开具，
         * notInvoiced-未开具
         */
        private String makeInvoiceStatus;

        /**
         * 红字确认单对应红票
         */
        private RedInvoice redInvoice;

        @Data
        public static class RedInvoice {

            /**
             * 发票号码
             */
            private String invoiceNo;

            /**
             * 发票类型
             * qc、qs、cz、sz
             */
            private String invoiceType;

            /**
             * 纸票发票代码（纸票红票有值）
             */
            private String paperInvoiceCode;

            /**
             * 纸票发票号码（纸票红票有值）
             */
            private String paperInvoiceNo;

            /**
             * 开票日期时间(yyyyMMddHHmmss)
             */
            private String dateIssued;

            /**
             * 二维码地址（纸票没有此字段）
             */
            private String qrCodeUrl;

            /**
             * 剩余开具额度
             */
            private BigDecimal creditLimit;

            /**
             * 剩余开具额度
             */
            private String remark;
        }
    }
}
